# -*- coding: utf-8 -*-
"""
Simple transfomer: the predefined XHTML and XHTML2 names are extended with the XHTML namespace for
later processing.

@author: U{Ivan Herman<a href="http://www.w3.org/People/Ivan/">}
@license: This software is available for use under the
U{W3C® SOFTWARE NOTICE AND LICENSE<href="http://www.w3.org/Consortium/Legal/2002/copyright-software-20021231">}
@contact: Ivan Herman, ivan@w3.org
@version: $Id: PredefinedProps.py,v 1.5 2007/10/04 13:02:46 ivan Exp $
$Date: 2007/10/04 13:02:46 $
"""

from pyRdfa.transform.utils import traverseTree, dump

XHTML_PREFIX = "xhtmlvocab"
XHTML_URI    = "http://www.w3.org/1999/xhtml/vocab#"


#### Predefined attributes
# List is taken from http://www.w3.org/MarkUp/2007/ED-xhtml-rdfa-20070811
__predefined_property = ['description', 'generator', 'keywords' 'reference', 'robots', 'title']

__predefined_rel      = ['alternate', 'appendix', 'bookmark', 'cite', 'chapter', 'contents',
'copyright', 'glossary', 'help', 'icon', 'index', 'meta', 'next', 'p3pv1', 'prev', 'profile',
'role', 'section', 'subsection', 'start', 'up']


def __settleAttr(attname,node,names,predef) :
	newProp  = ""
	change = False
	for n in names.strip().split() :
		nl = n.lower()
		if nl in predef :
			newProp += " " + XHTML_PREFIX + ":" + nl.lower()
			change = True
		else :
			newProp += " " + n
	if change:
		node.setAttribute(attname,newProp.strip())

def __manageProperty(node) :
	if node.hasAttribute("property") :
		names = node.getAttribute("property")
	else :
		return
	__settleAttr("property",node,names,__predefined_property)

def __manageRelRev(attname,node) :
	if node.hasAttribute(attname) :
		names = node.getAttribute(attname)
		__settleAttr(attname,node,names,__predefined_rel)


def __manageOneNode(node) :
	# settle the property
	__manageProperty(node)
	# settle the rel/rev
	__manageRelRev("rel",node)
	__manageRelRev("rev",node)
	return False


def PredefinedAttributeTransform(html) :
	"""
	@param html: a DOM node with the top level html element
	@param state: top level state
	"""
	# First, the xhtml namespace is added to the top, unless already there
	html.setAttributeNS("","xmlns:%s" % XHTML_PREFIX,XHTML_URI)
	traverseTree(html,__manageOneNode)

