# -*- coding: utf-8 -*-
"""
Utilities to be used by the various transformers

@author: U{Ivan Herman<a href="http://www.w3.org/People/Ivan/">}
@license: This software is available for use under the
U{W3C® SOFTWARE NOTICE AND LICENSE<href="http://www.w3.org/Consortium/Legal/2002/copyright-software-20021231">}
@contact: Ivan Herman, ivan@w3.org
@version: $Id: utils.py,v 1.4 2007/10/04 13:02:46 ivan Exp $
$Date: 2007/10/04 13:02:46 $
"""

from rdflib.RDF import RDFNS  as ns_rdf

def traverseTree(node,func) :
	"""Traverse the whole element tree, and perform the function 'func' on all the elements.
	If 'func' returns the value True, the traversal is stopped at that point.
	@param node: DOM element node
	@param func: function to be called on the node
	"""
	if func(node) :
		return

	for n in node.childNodes :
		if n.nodeType == node.ELEMENT_NODE :
			traverseTree(n,func)

def rdfPrefix(html) :
	"""Extract the top level prefix used for RDF. Although in most cases it is
	'rdf', we cannot be sure
	"""
	dict = {}
	for i in range(0,html.attributes.length) :
		attr = html.attributes.item(i)
		if attr.prefix == "xmlns" :
			# yep, there is a namespace setting
			key = attr.localName
			if key != "" :
				# exclude the top level xmlns setting...
				uri = attr.value
				if uri == ns_rdf.__str__() :
					return key

	# if it has not been set, the system will set it for 'rdf'...
	return 'rdf'

def _printNode(node) :
	debugStr = 'Node: %s, instanceof="%s" property="%s" rel="%s" rev="%s" resource="%s" about="%s"' % (node.tagName,node.getAttribute("instanceof"),node.getAttribute("property"),node.getAttribute("rel"),node.getAttribute("rev"),node.getAttribute("resource"),node.getAttribute("about"))
	print debugStr
	return False

def dump(node) :
	"""
	This is just for debug purposes: it dumps the tree starting at node...
	"""
	for i in range(0,node.attributes.length) :
		attr = node.attributes.item(i)
		if attr.prefix == "xmlns" :
			print "... %s:%s='%s'" % (attr.prefix,attr.localName,attr.value)

	traverseTree(node,_printNode)