from unittest import TestCase, makeSuite, TextTestRunner
from re import search
from StringIO import StringIO
from urllib2 import urlopen

from pyRdfa import processURI
from rdflib import Namespace
from rdflib.Graph import Graph
from rdflib.sparql.bison.Processor import Processor

class XhtmlTests (TestCase):
  """
  This test suite is generated automatically from the rdfa test manifest at:
  
  http://www.w3.org/2006/07/SWD/RDFa/testsuite/xhtml1-testcases/

  When this file is compiled a sparql query is executed against the 
  manifest, and a unittest TestCase is generated.
  """

def make_test(html_uri, sparql_uri, title):
  """
  Given an html_uri for some rdfa content, a uri for a sparql query to 
  execute, and the title of the test this function will create
  the test for it.
  """
  def test(self):
    rdf = processURI(html_uri)
    graph = Graph()
    graph.parse(StringIO(rdf))
    sparql = urlopen(sparql_uri).read()
    sparql_processor = Processor(graph)
    self.assertTrue(sparql_processor.query(sparql), title)
  return test

# query the RDFa test manifest and generate test methods in the 
# XhtmlTests unittest

q = """
PREFIX test: <http://www.w3.org/2006/03/test-description#> 
PREFIX dc:   <http://purl.org/dc/elements/1.1/>
SELECT ?html_uri ?sparql_uri ?title
FROM <http://www.w3.org/2006/07/SWD/RDFa/testsuite/xhtml1-testcases/rdfa-xhtml1-test-manifest.rdf>
WHERE 
{ 
  ?t dc:title ?title .
  ?t test:informationResourceInput ?html_uri .
  ?t test:informationResourceResults ?sparql_uri .
}
"""

g = Graph()
for html, sparql, title in g.query(q):
  num = search(r'(\d+)\.xhtml', html).groups(1)
  setattr(XhtmlTests, "test_%s" % num, make_test(html, sparql, title))

# when run from the command line this will execute each test
if __name__ == '__main__':
  suite = makeSuite(XhtmlTests)
  runner = TextTestRunner(descriptions=2, verbosity=2)
  runner.run(suite)

